@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import exceptions
 from etl import execute_etl
 from grammar import parse_query
 
@@ -11,38 +12,34 @@ def connect(g):
 class Connection(object):
 
     def __init__(self, graph):
+        """
+        :param graph: networkx.Graph
+        """
         self.graph = graph
         self._cursor = None
 
     def cursor(self):
-        if not self.graph:
-            raise Exception("Connection is closed.")
+        """
+        :returns: projx.Cursor
+        """
         cursor = Cursor(self)
         self._cursor = cursor
         return cursor
 
     def commit(self):
         if not getattr(self._cursor, "pending", ""):
-            raise Exception("Nothing to commit")
+            raise Warning("Nothing to commit")
         self.graph = self._cursor.pending
         self._cursor._pending = None
         
     def rollback(self):
-        try:
-            self._cursor._pending = None
-        except AttributeError:
-            raise Exception("Nothing to rollback")
+        if not getattr(self._cursor, "pending", ""):
+            raise Warning("Nothing to rollback")
+        self._cursor._pending = None
 
     def _reset_cursor(self):
         self._cursor = None
 
-    def close(self):
-        self.graph = None
-        self._cursor = None
-
-    def __del__(self):
-        self.close()
-
 
 class Cursor(object):
 
@@ -52,20 +49,17 @@ class Cursor(object):
         self._pending = None
 
     def _get_pending(self):
+        """
+        :returns: networkx.Graph
+        """
         return self._pending
     pending = property(fget=_get_pending)
 
     def execute(self, query):
-        if not self.graph:
-            raise Exception("Cursor has been closed.")
+        """
+        :param query: Str. projx DSL query.
+        :returns: networkx.Graph
+        """
         etl = parse_query(query)    
         self._pending = execute_etl(etl, self.graph)
         return self._pending
-
-    def close(self):
-        self._pending = None
-        self.graph = None
-        self.connection._reset_cursor()
-
-    def __del__(self):
-        self.close()
